summaryrefslogtreecommitdiffstats
path: root/src/widgets/text-toolbar.cpp
diff options
context:
space:
mode:
authorTavmjong Bah <tavmjong@free.fr>2016-09-05 13:44:11 +0000
committertavmjong-free <tavmjong@free.fr>2016-09-05 13:44:11 +0000
commite9d7e78e43ccfe0feda34998d31d921138232da6 (patch)
tree6a1062b3fce472214b96f4fd1b211f1bacec6b05 /src/widgets/text-toolbar.cpp
parentSave new 'x' and 'y' attribute values when 'line-height' changed. (diff)
downloadinkscape-e9d7e78e43ccfe0feda34998d31d921138232da6.tar.gz
inkscape-e9d7e78e43ccfe0feda34998d31d921138232da6.zip
Fix history handling for previous commit.
(bzr r15107)
Diffstat (limited to 'src/widgets/text-toolbar.cpp')
-rw-r--r--src/widgets/text-toolbar.cpp7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/widgets/text-toolbar.cpp b/src/widgets/text-toolbar.cpp
index 0ce2db4b2..4b22c8d7e 100644
--- a/src/widgets/text-toolbar.cpp
+++ b/src/widgets/text-toolbar.cpp
@@ -565,17 +565,18 @@ static void sp_text_lineheight_value_changed( GtkAdjustment *adj, GObject *tbl )
// Save for undo
if(modmade) {
- DocumentUndo::maybeDone(SP_ACTIVE_DESKTOP->getDocument(), "ttb:line-height", SP_VERB_NONE,
- _("Text: Change line-height"));
- // Call to Document::maybeDone() causes rebuild of text layout (with all proper style
+ // Call ensureUpToDate() causes rebuild of text layout (with all proper style
// cascading, etc.). For multi-line text with sodipodi::role="line", we must explicitly
// save new <tspan> 'x' and 'y' attribute values by calling updateRepr().
// Partial fix for bug #1590141.
+ desktop->getDocument()->ensureUpToDate();
for(auto i=itemlist.begin();i!=itemlist.end(); ++i){
if (SP_IS_TEXT (*i)) {
(*i)->updateRepr();
}
}
+ DocumentUndo::maybeDone(SP_ACTIVE_DESKTOP->getDocument(), "ttb:line-height", SP_VERB_NONE,
+ _("Text: Change line-height"));
}
// If no selected objects, set default.